@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FTN NetMail/EchoMail
  *
- * $Id: ftnaf.c,v 1.12 2003/02/16 15:38:52 n0ll Exp $
+ * $Id: ftnaf.c,v 1.14 2004/08/22 20:19:10 n0ll Exp $
  *
  * Areafix-like AREAS.BBS EchoMail distribution manager. Commands somewhat
  * conforming to FSC-0057.
  *
  *****************************************************************************
- * Copyright (C) 1990-2003
+ * Copyright (C) 1990-2004
  *  _____ _____
- * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * |     |___  |   Martin Junius             <mj.at.n0ll.dot.net>
  * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
@@ -39,7 +39,7 @@
 
 
 #define PROGRAM		"ftnaf"
-#define VERSION		"$Revision: 1.12 $"
+#define VERSION		"$Revision: 1.14 $"
 #define CONFIG		DEFAULT_CONFIG_MAIN
 
 
@@ -114,7 +114,7 @@ FILE *mailer_open(char *to)
     fp = popen(mailer, W_MODE);
     if(!fp)
     {
-	log("$ERROR: can't open pipe to %s", mailer);
+	logit("$ERROR: can't open pipe to %s", mailer);
 	return NULL;
     }
     
