@@ -2,14 +2,14 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FTN NetMail/EchoMail
  *
- * $Id: ftnafmail.c,v 1.8 2003/02/16 15:38:52 n0ll Exp $
+ * $Id: ftnafmail.c,v 1.10 2004/08/22 20:19:10 n0ll Exp $
  *
  * setuid frontend for ftnaf, limiting options for security reason
  *
  *****************************************************************************
- * Copyright (C) 1990-2003
+ * Copyright (C) 1990-2004
  *  _____ _____
- * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * |     |___  |   Martin Junius             <mj.at.n0ll.dot.net>
  * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
@@ -38,7 +38,7 @@
 
 
 #define PROGRAM		"ftnafmail"
-#define VERSION		"$Revision: 1.8 $"
+#define VERSION		"$Revision: 1.10 $"
 #define CONFIG		DEFAULT_CONFIG_MAIN
 
 
@@ -134,7 +134,7 @@ int main(int argc, char **argv)
     BUF_COPY(cmd, cf_p_libdir());
     BUF_APPEND(cmd, "/ftnaf");
     if( execv(cmd, filefix ? args_filefix : args_areafix) == ERROR )
-	log("$can't exec %s", cmd);
+	logit("$can't exec %s", cmd);
 	
     /* Only reached if error */
     exit(1);
