@@ -2,14 +2,14 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: ftnafpkt.c,v 1.15 2003/02/16 15:38:52 n0ll Exp $
+ * $Id: ftnafpkt.c,v 1.17 2004/08/22 20:19:10 n0ll Exp $
  *
  * Areafix processing FTN packets
  *
  *****************************************************************************
- * Copyright (C) 1990-2003
+ * Copyright (C) 1990-2004
  *  _____ _____
- * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * |     |___  |   Martin Junius             <mj.at.n0ll.dot.net>
  * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
@@ -37,7 +37,7 @@
 
 
 #define PROGRAM 	"ftnafpkt"
-#define VERSION 	"$Revision: 1.15 $"
+#define VERSION 	"$Revision: 1.17 $"
 #define CONFIG		DEFAULT_CONFIG_MAIN
 
 
@@ -119,7 +119,7 @@ int do_netmail(Message *msg, MsgBody *body)
  */
 int do_echomail(Message *msg, MsgBody *body)
 {
-    log("echomail message from %s not processed", znfp1(&msg->node_orig));
+    logit("echomail message from %s not processed", znfp1(&msg->node_orig));
     
     return OK;
 }
@@ -147,11 +147,11 @@ int do_packet(FILE *pkt_file, Packet *pkt)
     {
 	if(feof(pkt_file))
 	{
-	    log("WARNING: premature EOF reading input packet");
+	    logit("WARNING: premature EOF reading input packet");
 	    TMPS_RETURN(OK);
 	}
 	
-	log("ERROR: reading input packet");
+	logit("ERROR: reading input packet");
 	TMPS_RETURN(ERROR);
     }
 
@@ -162,7 +162,7 @@ int do_packet(FILE *pkt_file, Packet *pkt)
 	msg.node_to   = pkt->to;
 	if(pkt_get_msg_hdr(pkt_file, &msg) == ERROR)
 	{
-	    log("ERROR: reading input packet");
+	    logit("ERROR: reading input packet");
 	    TMPS_RETURN(ERROR);
 	}
 	
@@ -172,18 +172,18 @@ int do_packet(FILE *pkt_file, Packet *pkt)
 	{
 	    if(feof(pkt_file))
 	    {
-		log("WARNING: premature EOF reading input packet");
+		logit("WARNING: premature EOF reading input packet");
 	    }
 	    else
 	    {
-		log("ERROR: reading input packet");
+		logit("ERROR: reading input packet");
 		TMPS_RETURN(ERROR);
 	    }
 	}
 	
 	/* Parse message body */
 	if( msg_body_parse(&tl, &body) == -2 )
-	    log("ERROR: parsing message body");
+	    logit("ERROR: parsing message body");
 	/* Retrieve address information from kludges for NetMail */
 	if(body.area == NULL)
 	{
@@ -235,13 +235,13 @@ int do_file(char *pkt_name)
     /* Open packet and read header */
     pkt_file = fopen(pkt_name, R_MODE);
     if(!pkt_file) {
-	log("$ERROR: can't open packet %s", pkt_name);
+	logit("$ERROR: can't open packet %s", pkt_name);
 	rename_bad(pkt_name);
 	TMPS_RETURN(OK);
     }
     if(pkt_get_hdr(pkt_file, &pkt) == ERROR)
     {
-	log("ERROR: reading header from %s", pkt_name);
+	logit("ERROR: reading header from %s", pkt_name);
 	fclose(pkt_file);
 	rename_bad(pkt_name);
 	TMPS_RETURN(OK);
@@ -249,12 +249,12 @@ int do_file(char *pkt_name)
     
     /* Process it */
     pkt_size = check_size(pkt_name);
-    log("packet %s (%ldb) from %s to %s", pkt_name, pkt_size,
+    logit("packet %s (%ldb) from %s to %s", pkt_name, pkt_size,
 	znfp1(&pkt.from), znfp2(&pkt.to) );
     
     if(do_packet(pkt_file, &pkt) == ERROR) 
     {
-	log("ERROR: processing %s", pkt_name);
+	logit("ERROR: processing %s", pkt_name);
 	fclose(pkt_file);
 	rename_bad(pkt_name);
 	TMPS_RETURN(severe_error);
@@ -263,7 +263,7 @@ int do_file(char *pkt_name)
     fclose(pkt_file);
 
     if (unlink(pkt_name)) {
-	log("$ERROR: can't unlink %s", pkt_name);
+	logit("$ERROR: can't unlink %s", pkt_name);
 	rename_bad(pkt_name);
 	TMPS_RETURN(ERROR);
     }
@@ -294,7 +294,7 @@ void prog_signal(int signum)
 	name = "";            break;
     }
 
-    log("KILLED%s: exit forced", name);
+    logit("KILLED%s: exit forced", name);
 }
 
 
@@ -455,7 +455,7 @@ int main(int argc, char **argv)
 	dir_sortmode(DIR_SORTMTIME);
 	if(dir_open(in_dir, "*.pkt", TRUE) == ERROR)
 	{
-	    log("$ERROR: can't open directory %s", in_dir);
+	    logit("$ERROR: can't open directory %s", in_dir);
 	    exit(EXIT_ERROR);
 	}
     
