@@ -2,14 +2,14 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FTN NetMail/EchoMail
  *
- * $Id: ftnafutil.c,v 1.14 2003/02/16 15:38:52 n0ll Exp $
+ * $Id: ftnafutil.c,v 1.16 2004/08/22 20:19:10 n0ll Exp $
  *
  * Utility program for Areafix.
  *
  *****************************************************************************
- * Copyright (C) 1990-2003
+ * Copyright (C) 1990-2004
  *  _____ _____
- * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * |     |___  |   Martin Junius             <mj.at.n0ll.dot.net>
  * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
@@ -36,7 +36,7 @@
 
 
 #define PROGRAM		"ftnafutil"
-#define VERSION		"$Revision: 1.14 $"
+#define VERSION		"$Revision: 1.16 $"
 #define CONFIG		DEFAULT_CONFIG_MAIN
 
 
@@ -81,7 +81,7 @@ int do_mail(Node *node, char *area, char *s, Passwd *pwd)
 
     if(!pwd || !pwd->passwd)
     {
-	log("ERROR: no uplink password for %s, can't send request", 
+	logit("ERROR: no uplink password for %s, can't send request", 
 	    znfp1(node));
 	return ERROR;
     }
@@ -143,7 +143,7 @@ int do_areasbbs(int cmd)
 	case DO_DELETE:
 	    if(!uplink)
 	    {
-		log("area %s: no uplink, deleting", p->area);
+		logit("area %s: no uplink, deleting", p->area);
 		if(!n_flag) 
 		{
 		    areasbbs_remove(p, pl);
@@ -159,7 +159,7 @@ int do_areasbbs(int cmd)
 	    {
 		if(! (pwd = passwd_lookup("uplink", uplink)) )
 		    break;
-		log("area %s: #dl=%d state=%s, subscribing at uplink %s",
+		logit("area %s: #dl=%d state=%s, subscribing at uplink %s",
 		      p->area, n, state, znfp1(uplink));
 		if(!n_flag && do_mail(uplink, p->area, "+", pwd) != ERROR)
 		{
@@ -175,7 +175,7 @@ int do_areasbbs(int cmd)
 	    {
 		if(! (pwd = passwd_lookup("uplink", uplink)) )
 		    break;
-		log("area %s: #dl=%d state=%s, unsubscribing at uplink %s",
+		logit("area %s: #dl=%d state=%s, unsubscribing at uplink %s",
 		      p->area, n, state, znfp1(uplink));
 		if(!n_flag && do_mail(uplink, p->area, "-", pwd) != ERROR)
 		{
