@@ -2,14 +2,14 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FTN NetMail/EchoMail
  *
- * $Id: charset.c,v 1.11 2003/02/16 15:38:52 n0ll Exp $
+ * $Id: charset.c,v 1.13 2004/08/22 20:19:10 n0ll Exp $
  *
  * NEW charset.c code using charset.bin mapping file
  *
  *****************************************************************************
- * Copyright (C) 1990-2003
+ * Copyright (C) 1990-2004
  *  _____ _____
- * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * |     |___  |   Martin Junius             <mj.at.n0ll.dot.net>
  * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
@@ -321,7 +321,7 @@ void charset_init(void)
 {
     if(charset_read_bin( cf_p_charsetmap() ) == ERROR) 
     {
-	log("ERROR: reading from %s", cf_p_charsetmap());
+	logit("ERROR: reading from %s", cf_p_charsetmap());
 	exit(EX_SOFTWARE);
     }
 
