@@ -2,14 +2,14 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FTN NetMail/EchoMail
  *
- * $Id: rematch.c,v 4.8 2003/02/16 15:38:57 n0ll Exp $
+ * $Id: rematch.c,v 4.10 2004/08/22 20:19:11 n0ll Exp $
  *
  * Regular expression (POSIX functions) handling for FIDOGATE
  *
  *****************************************************************************
- * Copyright (C) 1990-2003
+ * Copyright (C) 1990-2004
  *  _____ _____
- * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * |     |___  |   Martin Junius             <mj.at.n0ll.dot.net>
  * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
@@ -86,7 +86,7 @@ static Regex *regex_parse_line(char *s)
     p->re_s = strsave(s);
     err = regcomp(&p->re_c, p->re_s, REG_EXTENDED|REG_ICASE);
     if(err) {
-	log("WARNING: error compiling regex %s", p->re_s);
+	logit("WARNING: error compiling regex %s", p->re_s);
 	xfree(p);
 	return NULL;
     }
