@@ -2,14 +2,14 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: ftn2rfc.c,v 4.62 2003/02/16 15:39:00 n0ll Exp $
+ * $Id: ftn2rfc.c,v 4.65 2004/08/22 20:19:12 n0ll Exp $
  *
  * Convert FTN mail packets to RFC mail and news batches
  *
  *****************************************************************************
- * Copyright (C) 1990-2003
+ * Copyright (C) 1990-2004
  *  _____ _____
- * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * |     |___  |   Martin Junius             <mj.at.n0ll.dot.net>
  * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
@@ -40,7 +40,7 @@
 
 
 #define PROGRAM 	"ftn2rfc"
-#define VERSION 	"$Revision: 4.62 $"
+#define VERSION 	"$Revision: 4.65 $"
 #define CONFIG		DEFAULT_CONFIG_GATE
 
 
@@ -337,11 +337,11 @@ int unpack(FILE *pkt_file, Packet *pkt)
     {
 	if(feof(pkt_file))
 	{
-	    log("WARNING: premature EOF reading input packet");
+	    logit("WARNING: premature EOF reading input packet");
 	    return OK;
 	}
 	
-	log("ERROR: reading input packet");
+	logit("ERROR: reading input packet");
 	return ERROR;
     }
 
@@ -358,7 +358,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	msg.node_to   = pkt->to;
 	if( pkt_get_msg_hdr(pkt_file, &msg) == ERROR )
 	{
-	    log("ERROR: reading input packet");
+	    logit("ERROR: reading input packet");
 	    ret = ERROR;
 	    break;
 	}
@@ -380,11 +380,11 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	{
 	    if(feof(pkt_file))
 	    {
-		log("WARNING: premature EOF reading input packet");
+		logit("WARNING: premature EOF reading input packet");
 	    }
 	    else
 	    {
-		log("ERROR: reading input packet");
+		logit("ERROR: reading input packet");
 		ret = ERROR;
 		tl_clear(&theader);
 		tl_clear(&tbody);
@@ -398,7 +398,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	 * Parse message body
 	 */
 	if( msg_body_parse(&tl, &body) == -2 )
-	    log("ERROR: parsing message body");
+	    logit("ERROR: parsing message body");
 	/* Retrieve address information from kludges for NetMail */
 	if(body.area == NULL)
 	{
@@ -471,7 +471,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    /* Skip, if unknown and FTNJunkGroup not set */
 	    if(!area->group && !ftn_junk_group)
 	    {
-		log("unknown area %s", area->area);
+		logit("unknown area %s", area->area);
 		tl_clear(&theader);
 		tl_clear(&tbody);
 		tl_clear(&tl);
@@ -647,7 +647,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    /* ^A SPLIT */
 	    if( (p = kludge_get(&body.kludge, "SPLIT", NULL)) )
 	    {
-		log("skipping split message, origin=%s", znfp1(&msg.node_orig));
+		logit("skipping split message, origin=%s", znfp1(&msg.node_orig));
 		tl_clear(&theader);
 		tl_clear(&tbody);
 		tl_clear(&tl);
@@ -664,7 +664,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	{
 	    if(msgbody_rfc_from)
 	    {
-		log("skipping message from gateway, area %s, origin=%s",
+		logit("skipping message from gateway, area %s, origin=%s",
 		    area->area, znfp1(&msg.node_orig));
 		tl_clear(&theader);
 		tl_clear(&tbody);
@@ -677,7 +677,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    if( (p = kludge_get(&body.kludge, "PID", NULL))  &&
 	       !strnicmp(p, "GIGO", 4)                         )
 	    {
-		log("skipping message from gateway (GIGO), area %s, origin=%s",
+		logit("skipping message from gateway (GIGO), area %s, origin=%s",
 		    area->area, znfp1(&msg.node_orig));
 		tl_clear(&theader);
 		tl_clear(&tbody);
@@ -689,7 +689,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    /* Broken FidoZerb message splitting */
 	    if( (p = kludge_get(&body.kludge, "X-FZ-SPLIT", NULL)) )
 	    {
-		log("skipping message from gateway (X-FZ-SPLIT), area %s, origin=%s",
+		logit("skipping message from gateway (X-FZ-SPLIT), area %s, origin=%s",
 		    area->area, znfp1(&msg.node_orig));
 		tl_clear(&theader);
 		tl_clear(&tbody);
@@ -764,7 +764,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	if(area==NULL && t_flag && msgbody_rfc_to)
 	{
 	    debug(1, "Insecure message with To line");
-	    log("BOUNCE: insecure mail from %s",
+	    logit("BOUNCE: insecure mail from %s",
 		s_rfcaddr_to_asc(&addr_from, TRUE));
 	    bounce_mail("insecure", &addr_from, &msg, msgbody_rfc_to, &tbody);
 	    tl_clear(&theader);
@@ -810,7 +810,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 		/* Not registered in HOSTS */
 		debug(1, "Not a registered node: %s",
 		      znfp1(&msg.node_orig));
-		log("BOUNCE: mail from unregistered %s",
+		logit("BOUNCE: mail from unregistered %s",
 		    s_rfcaddr_to_asc(&addr_from, TRUE));
 		bounce_mail("restricted", &addr_from, &msg,
 			    msgbody_rfc_to, &tbody);
@@ -826,7 +826,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    {
 		debug(1, "Registered node is down: %s",
 		      znfp1(&msg.node_orig));
-		log("BOUNCE: mail from down %s",
+		logit("BOUNCE: mail from down %s",
 		    s_rfcaddr_to_asc(&addr_from, TRUE));
 		bounce_mail("down", &addr_from, &msg,
 			    msgbody_rfc_to, &tbody);
@@ -849,7 +849,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 		if(no_address_in_to_field)
 		{
 		    debug(1, "Message with address in mail_to: %s", mail_to);
-		    log("BOUNCE: mail from %s with address in to field: %s",
+		    logit("BOUNCE: mail from %s with address in to field: %s",
 			s_rfcaddr_to_asc(&addr_from, TRUE), mail_to           );
 		    bounce_mail("addrinto",
 				&addr_from, &msg, msgbody_rfc_to, &tbody);
@@ -879,7 +879,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    {
 		/* Addressed to `UUCP' or `GATEWAY', but no To: line */
 		debug(1, "Message to `UUCP' or `GATEWAY' without To line");
-		log("BOUNCE: mail from %s without To line",
+		logit("BOUNCE: mail from %s without To line",
 		    s_rfcaddr_to_asc(&addr_from, TRUE));
 		bounce_mail("noto", &addr_from, &msg, msgbody_rfc_to, &tbody);
 		tl_clear(&theader);
@@ -958,7 +958,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    {
 		if(!strncmp(p, "<NOMSGID_", 9))
 		{
-		    log("MSGID: %s, not gated", p);
+		    logit("MSGID: %s, not gated", p);
 		    tl_clear(&theader);
 		    tl_clear(&tbody);
 		    tl_clear(&tl);
@@ -969,7 +969,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 		if(no_unknown_msgid_zones)
 		    if(id_zone>=-1 && !cf_zones_check(id_zone))
 		    {
-			log("MSGID %s: malformed or unknown zone, not gated", p);
+			logit("MSGID %s: malformed or unknown zone, not gated", p);
 			tl_clear(&theader);
 			tl_clear(&tbody);
 			tl_clear(&tl);
@@ -981,7 +981,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    {
 		if(no_messages_without_msgid)
 		{
-		    log("MSGID: none, not gated");
+		    logit("MSGID: none, not gated");
 		    tl_clear(&theader);
 		    tl_clear(&tbody);
 		    tl_clear(&tl);
@@ -994,7 +994,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	/* Can't happen, but who knows ... ;-) */
 	if(!id_line)
 	{
-	    log("ERROR: id_line==NULL, strange.");
+	    logit("ERROR: id_line==NULL, strange.");
 	    tl_clear(&theader);
 	    tl_clear(&tbody);
 	    tl_clear(&tl);
@@ -1018,7 +1018,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 
 	/* Different header for mail and news */
 	if(area==NULL) {			/* Mail */
-	    log("MAIL: %s -> %s", from_line, to_line);
+	    logit("MAIL: %s -> %s", from_line, to_line);
 	    
 	    tl_appendf(&theader,
 		       "From %s %s\n", s_rfcaddr_to_asc(&addr_from, FALSE),
@@ -1090,6 +1090,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	}
 	
 	/* Common header */
+	p = NULL;
 	if(use_origin_for_organization && body.origin)
 	{
 	    strip_crlf(body.origin);
@@ -1104,12 +1105,13 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    p = buffer + strlen(" * Origin: ");
 	    while(is_blank(*p))
 		p++;
-	    tl_appendf(&theader, "Organization: %s\n", p);
-	}
-	else
-	{
-	    tl_appendf(&theader, "Organization: %s\n", cf_p_organization() );
+	    if(!*p)
+		p = NULL;
 	}
+	if(!p)
+	    p = cf_p_organization();
+	tl_appendf(&theader, "Organization: %s\n", p);
+
 	tl_appendf(&theader, "Lines: %d\n", lines);
 	if(gateway)
 	    tl_appendf(&theader, "X-Gateway: FIDO %s [FIDOGATE %s], %s\n",
@@ -1258,7 +1260,7 @@ int unpack_file(char *pkt_name)
     /* Open packet and read header */
     pkt_file = fopen(pkt_name, R_MODE);
     if(!pkt_file) {
-	log("$ERROR: can't open packet %s", pkt_name);
+	logit("$ERROR: can't open packet %s", pkt_name);
 	if(n_flag)
 	    return ERROR;
 	else
@@ -1269,7 +1271,7 @@ int unpack_file(char *pkt_name)
     }
     if(pkt_get_hdr(pkt_file, &pkt) == ERROR)
     {
-	log("ERROR: reading header from %s", pkt_name);
+	logit("ERROR: reading header from %s", pkt_name);
 	if(n_flag)
 	    return ERROR;
 	else
@@ -1280,12 +1282,12 @@ int unpack_file(char *pkt_name)
     }
     
     /* * Unpack it */
-    log("packet %s (%ldb) from %s to %s", pkt_name, check_size(pkt_name),
+    logit("packet %s (%ldb) from %s to %s", pkt_name, check_size(pkt_name),
 	znfp1(&pkt.from), znfp2(&pkt.to) );
     
     if(unpack(pkt_file, &pkt) == ERROR) 
     {
-	log("ERROR: processing %s", pkt_name);
+	logit("ERROR: processing %s", pkt_name);
 	if(n_flag)
 	    return ERROR;
 	else
@@ -1298,7 +1300,7 @@ int unpack_file(char *pkt_name)
     fclose(pkt_file);
     
     if(!n_flag && unlink(pkt_name)==ERROR) {
-	log("$ERROR: can't unlink packet %s", pkt_name);
+	logit("$ERROR: can't unlink packet %s", pkt_name);
 	rename_bad(pkt_name);
 	return OK;
     }
@@ -1629,7 +1631,7 @@ int main(int argc, char **argv)
 	dir_sortmode(DIR_SORTMTIME);
 	if(dir_open(in_dir, "*.pkt", TRUE) == ERROR)
 	{
-	    log("$ERROR: can't open directory %s", in_dir);
+	    logit("$ERROR: can't open directory %s", in_dir);
 	    if(l_flag)
 		unlock_program(PROGRAM);
 	    exit(EX_OSERR);
