@@ -2,14 +2,14 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway software UNIX <-> FIDO
  *
- * $Id: rfc2ftn.c,v 4.70 2003/02/16 15:39:01 n0ll Exp $
+ * $Id: rfc2ftn.c,v 4.74 2004/08/22 20:19:12 n0ll Exp $
  *
  * Read mail or news from standard input and convert it to a FIDO packet.
  *
  *****************************************************************************
- * Copyright (C) 1990-2003
+ * Copyright (C) 1990-2004
  *  _____ _____
- * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * |     |___  |   Martin Junius             <mj.at.n0ll.dot.net>
  * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
@@ -39,7 +39,7 @@
 
 
 #define PROGRAM 	"rfc2ftn"
-#define VERSION 	"$Revision: 4.70 $"
+#define VERSION 	"$Revision: 4.74 $"
 #define CONFIG		DEFAULT_CONFIG_GATE
 
 
@@ -122,6 +122,7 @@ static int dont_process_return_receipt_to = FALSE;
 					/* DontProcessReturnReceiptTo */
 static int registered_hosts_only = FALSE;	/* RegisteredHostsOnly */
 static int registered_aliases_only = FALSE;	/* RegisteredAliasesOnly */
+static int silent_bounces = FALSE;	/* SilentBounces */
 
 
 /* Charset stuff */
@@ -700,6 +701,10 @@ char *receiver(char *to, Node *node)
 	return name;
     }
 
+    /* Sysop is always OK */
+    if(!stricmp(name, "sysop"))
+	return name;
+
     /* If RegisteredAliasesOnly is set, flag missing alias as error */
     if(!newsmode && registered_aliases_only) 
     {
@@ -731,8 +736,10 @@ char *mail_receiver(RFCAddr *rfc, Node *node)
 	 * Address is argument
 	 */
 	if(rfc_parse(rfc, name, node, TRUE) == ERROR) {
-	    log("BOUNCE: to=%s, reject=%s", s_rfcaddr_to_asc(rfc, TRUE),
+#if 0
+	    logit("BOUNCE: to=%s, reject=%s", s_rfcaddr_to_asc(rfc, TRUE),
 		(*address_error ? address_error : "unknown")  );
+#endif
 	    return NULL;
 	}
     }
@@ -909,12 +916,23 @@ int snd_mail(RFCAddr rfc_to, long size)
     p = mail_receiver(&rfc_to, &node_to);
     if(!p) {
 	char *msg = *address_error ? address_error : "address/host is unknown";
-	
-	sendback("Address %s:\n  %s", s_rfcaddr_to_asc(&rfc_to, TRUE), msg);
-	log("BOUNCE: from=%s, to=%s, reject=%s",
-	    s_rfcaddr_to_asc(&rfc_from, TRUE),
-	    s_rfcaddr_to_asc(&rfc_to, TRUE), msg);
-	TMPS_RETURN(address_exit ? address_exit : EX_NOHOST);
+
+	if(silent_bounces) 
+	{
+	    logit("BOUNCE: from=%s, to=%s, reject=%s (SILENT!)",
+		s_rfcaddr_to_asc(&rfc_from, TRUE),
+		s_rfcaddr_to_asc(&rfc_to, TRUE), msg);
+	    TMPS_RETURN(OK);
+	}
+	else 
+	{
+	    sendback("Address %s:\n  %s",
+		     s_rfcaddr_to_asc(&rfc_to, TRUE), msg);
+	    logit("BOUNCE: from=%s, to=%s, reject=%s",
+		s_rfcaddr_to_asc(&rfc_from, TRUE),
+		s_rfcaddr_to_asc(&rfc_to, TRUE), msg);
+	    TMPS_RETURN(address_exit ? address_exit : EX_NOHOST);
+	}
     }
     BUF_COPY(msg.name_to, p);
     fido = rfc_isfido();
@@ -963,7 +981,7 @@ int snd_mail(RFCAddr rfc_to, long size)
 	if(limitsize>0 && size>limitsize)
 	{
 	    /* Too large, don't gate it */
-	    log("BOUNCE: from=%s, to=%s, "
+	    logit("BOUNCE: from=%s, to=%s, "
 		"reject=message too big (%ldb, limit %ldb)",
 		s_rfcaddr_to_asc(&rfc_from, TRUE),
 		s_rfcaddr_to_asc(&rfc_to, TRUE), size, limitsize );
@@ -989,14 +1007,14 @@ int snd_mail(RFCAddr rfc_to, long size)
 		else
 		{
 		    if(flags)
-			log("NON-LOCAL From: %s, Reply-To: %s, X-Flags: %s",
+			logit("NON-LOCAL From: %s, Reply-To: %s, X-Flags: %s",
 			    hf ? hf : "<>", hr ? hr : "<>", flags           );
 		    flags = p = NULL;
 		}
 	    }
 	    /* Let's at least log what's going on ... */
 	    if(flags)
-		log("X-Flags: %s, From: %s", flags, hf ? hf : "<>");
+		logit("X-Flags: %s, From: %s", flags, hf ? hf : "<>");
 	    
 	    p = flags;
 	    if(p)
@@ -1028,7 +1046,7 @@ int snd_mail(RFCAddr rfc_to, long size)
 
 	    /* Log what's going on ... */
 	    if(flags)
-		log("FORBIDDEN X-Flags: %s, From: %s", flags, hf ? hf : "<>");
+		logit("FORBIDDEN X-Flags: %s, From: %s", flags, hf ? hf : "<>");
 	    flags = NULL;
 	}
 	
@@ -1130,12 +1148,12 @@ int snd_mail(RFCAddr rfc_to, long size)
 		{
 		    if(pna_notify(s_rfcaddr_to_asc(&rfc_from, FALSE)))
 		    {
-			log("BOUNCE: Postings from address `%s' to group `%s' not allowed - skipped, sent notify",
+			logit("BOUNCE: Postings from address `%s' to group `%s' not allowed - skipped, sent notify",
 			    s_rfcaddr_to_asc(&rfc_from, FALSE), pa->group);
 			bounce_mail("acl", &rfc_from, &msg, pa->group, &body);
 		    }
 		    else
-			log("BOUNCE: Postings from address `%s' to group `%s' not allowed - skipped",
+			logit("BOUNCE: Postings from address `%s' to group `%s' not allowed - skipped",
 			    s_rfcaddr_to_asc(&rfc_from, FALSE), pa->group);
 		    continue;
 		}
@@ -1145,7 +1163,7 @@ int snd_mail(RFCAddr rfc_to, long size)
 		if(limitsize>0 && size>limitsize)
 		{
 		    /* Too large, don't gate it */
-		    log("message too big (%ldb, limit %ldb) for area %s",
+		    logit("message too big (%ldb, limit %ldb) for area %s",
 			size, limitsize, pa->area                        );
 		    continue;
 		}
@@ -1170,7 +1188,7 @@ int snd_mail(RFCAddr rfc_to, long size)
 	/*
 	 * NetMail message
 	 */
-	log("MAIL: from=%s, to=%s",
+	logit("MAIL: from=%s, to=%s",
 	    s_rfcaddr_to_asc(&rfc_from, TRUE),
 	    s_rfcaddr_to_asc(&rfc_to, TRUE));
 	msg.area      = NULL;
@@ -2037,7 +2055,7 @@ int main(int argc, char **argv)
 	debug(8, "config: MaxMsgSize %s", p);
 	sz = atol(p);
 	if(sz <= 0)
-	    log("WARNING: illegal MaxMsgSize value %s", p);
+	    logit("WARNING: illegal MaxMsgSize value %s", p);
 	else
 	    areas_maxmsgsize(sz);
     }
@@ -2048,7 +2066,7 @@ int main(int argc, char **argv)
 	debug(8, "config: LimitMsgSize %s", p);
 	sz = atol(p);
 	if(sz <= 0)
-	    log("WARNING: illegal LimitMsgSize value %s", p);
+	    logit("WARNING: illegal LimitMsgSize value %s", p);
 	else
 	    areas_limitmsgsize(sz);
     }
@@ -2166,6 +2184,10 @@ int main(int argc, char **argv)
     {
 	registered_aliases_only = TRUE;
     }
+    if( (p = cf_get_string("SilentBounces", TRUE)) )
+    {
+	silent_bounces = TRUE;
+    }
 
 
     /*
@@ -2224,7 +2246,7 @@ int main(int argc, char **argv)
 	    debug(3, "re-positioning to offset %ld", pos);
 	    fclose(fppos);
 	    if( fseek(fp, pos, SEEK_SET) == ERROR )
-		log("$WARNING: can't seek to offset %ld in file %s",
+		logit("$WARNING: can't seek to offset %ld in file %s",
 		    pos, f_flag);
 	}
     }
@@ -2271,7 +2293,7 @@ int main(int argc, char **argv)
 	{
 	    size = read_rnews_size(fpart);
 	    if(size == -1)
-		log("ERROR: reading news batch");
+		logit("ERROR: reading news batch");
 	    if(size <= 0)
 		break;
 	    debug(3, "Batch: message #%ld size %ld", nmsg, size);
